API Reference — eprllib: use EnergyPlus as an environment for DRL control

Skip to main content
`Ctrl`+`K`

# API Reference

Here is the reference documentation to the eprllib API.

## eprllib

The package eprllib provides a set of tools for the development of energy performance research in the context of the Python programming language. The package is structured as follows:

Modules

`ActionFunctions` | Action Functions
`Agents` | Agents
`Env` | Environments
`EpisodeFunctions` | Episode Functions
`PostProcess` | Post Process Functions
`RewardFunctions` | Reward Functions